@@ -7,9 +7,9 @@
 #include "caldavprotocol_p.h"
 #include "common/utils_p.h"
 
+#include <QDomDocument>
 #include <QStringList>
 #include <QUrl>
-#include <QDomDocument>
 
 using namespace KDAV;
 
@@ -260,7 +260,7 @@ public:
         for (const QString &url : urls) {
             QDomElement hrefElement = document.createElementNS(QStringLiteral("DAV:"), QStringLiteral("href"));
             const QUrl pathUrl = QUrl::fromUserInput(url);
-            const QDomText textNode = document.createTextNode(pathUrl.toString());
+            const QDomText textNode = document.createTextNode(pathUrl.path());
             hrefElement.appendChild(textNode);
 
             multigetElement.appendChild(hrefElement);
@@ -309,13 +309,9 @@ XMLQueryBuilder::Ptr CaldavProtocol::collectionsQuery() const
     return XMLQueryBuilder::Ptr(new CaldavCollectionQueryBuilder());
 }
 
-QString CaldavProtocol::collectionsXQuery() const
+bool CaldavProtocol::containsCollection(const QDomElement &propElem) const
 {
-    //const QString query( "//*[local-name()='calendar' and namespace-uri()='urn:ietf:params:xml:ns:caldav']/ancestor::*[local-name()='prop' and namespace-uri()='DAV:']/*[local-name()='supported-calendar-component-set' and namespace-uri()='urn:ietf:params:xml:ns:caldav']/*[local-name()='comp' and namespace-uri()='urn:ietf:params:xml:ns:caldav' and (@name='VTODO' or @name='VEVENT')]/ancestor::*[local-name()='response' and namespace-uri()='DAV:']" );
-    const QString query(QStringLiteral(
-                            "//*[local-name()='calendar' and namespace-uri()='urn:ietf:params:xml:ns:caldav']/ancestor::*[local-name()='prop' and namespace-uri()='DAV:']/ancestor::*[local-name()='response' and namespace-uri()='DAV:']"));
-
-    return query;
+    return !propElem.elementsByTagNameNS(QStringLiteral("urn:ietf:params:xml:ns:caldav"), QStringLiteral("calendar")).isEmpty();
 }
 
 QVector<XMLQueryBuilder::Ptr> CaldavProtocol::itemsQueries() const
@@ -369,7 +365,9 @@ DavCollection::ContentTypes CaldavProtocol::collectionContentTypes(const QDomEle
      */
 
     const QDomElement propElement = Utils::firstChildElementNS(propstatElement, QStringLiteral("DAV:"), QStringLiteral("prop"));
-    const QDomElement supportedcomponentElement = Utils::firstChildElementNS(propElement, QStringLiteral("urn:ietf:params:xml:ns:caldav"), QStringLiteral("supported-calendar-component-set"));
+    const QDomElement supportedcomponentElement = Utils::firstChildElementNS(propElement, //
+                                                                             QStringLiteral("urn:ietf:params:xml:ns:caldav"),
+                                                                             QStringLiteral("supported-calendar-component-set"));
 
     DavCollection::ContentTypes contentTypes;
     QDomElement compElement = Utils::firstChildElementNS(supportedcomponentElement, QStringLiteral("urn:ietf:params:xml:ns:caldav"), QStringLiteral("comp"));
